==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/SqlConnectionInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.SqlConnectionInfoArgs.builder
import com.pulumi.azurenative.datamigration.kotlin.enums.AuthenticationType
import com.pulumi.azurenative.datamigration.kotlin.enums.SqlSourcePlatform
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Information for connecting to SQL database server
 * @property additionalSettings Additional connection settings
 * @property authentication Authentication type to use for connection
 * @property dataSource Data source in the format Protocol:MachineName\SQLServerInstanceName,PortNumber
 * @property encryptConnection Whether to encrypt the connection
 * @property password Password credential.
 * @property platform Server platform type for connection
 * @property trustServerCertificate Whether to trust the server certificate
 * @property type Type of connection info
 * Expected value is 'SqlConnectionInfo'.
 * @property userName User name
 */
public data class SqlConnectionInfoArgs(
    public val additionalSettings: Output<String>? = null,
    public val authentication: Output<Either<String, AuthenticationType>>? = null,
    public val dataSource: Output<String>,
    public val encryptConnection: Output<Boolean>? = null,
    public val password: Output<String>? = null,
    public val platform: Output<Either<String, SqlSourcePlatform>>? = null,
    public val trustServerCertificate: Output<Boolean>? = null,
    public val type: Output<String>,
    public val userName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.SqlConnectionInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.datamigration.inputs.SqlConnectionInfoArgs =
        com.pulumi.azurenative.datamigration.inputs.SqlConnectionInfoArgs.builder()
            .additionalSettings(additionalSettings?.applyValue({ args0 -> args0 }))
            .authentication(
                authentication?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .dataSource(dataSource.applyValue({ args0 -> args0 }))
            .encryptConnection(encryptConnection?.applyValue({ args0 -> args0 }))
            .password(password?.applyValue({ args0 -> args0 }))
            .platform(
                platform?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .trustServerCertificate(trustServerCertificate?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 }))
            .userName(userName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SqlConnectionInfoArgs].
 */
@PulumiTagMarker
public class SqlConnectionInfoArgsBuilder internal constructor() {
    private var additionalSettings: Output<String>? = null

    private var authentication: Output<Either<String, AuthenticationType>>? = null

    private var dataSource: Output<String>? = null

    private var encryptConnection: Output<Boolean>? = null

    private var password: Output<String>? = null

    private var platform: Output<Either<String, SqlSourcePlatform>>? = null

    private var trustServerCertificate: Output<Boolean>? = null

    private var type: Output<String>? = null

    private var userName: Output<String>? = null

    /**
     * @param value Additional connection settings
     */
    @JvmName("bojsqvbopelkhcli")
    public suspend fun additionalSettings(`value`: Output<String>) {
        this.additionalSettings = value
    }

    /**
     * @param value Authentication type to use for connection
     */
    @JvmName("vecvygppjroagtkv")
    public suspend fun authentication(`value`: Output<Either<String, AuthenticationType>>) {
        this.authentication = value
    }

    /**
     * @param value Data source in the format Protocol:MachineName\SQLServerInstanceName,PortNumber
     */
    @JvmName("jbnywktftfbngdac")
    public suspend fun dataSource(`value`: Output<String>) {
        this.dataSource = value
    }

    /**
     * @param value Whether to encrypt the connection
     */
    @JvmName("ituehbuhyqhgvsql")
    public suspend fun encryptConnection(`value`: Output<Boolean>) {
        this.encryptConnection = value
    }

    /**
     * @param value Password credential.
     */
    @JvmName("pgqxkpqvxwhefrgr")
    public suspend fun password(`value`: Output<String>) {
        this.password = value
    }

    /**
     * @param value Server platform type for connection
     */
    @JvmName("vnfuwyqsknielgby")
    public suspend fun platform(`value`: Output<Either<String, SqlSourcePlatform>>) {
        this.platform = value
    }

    /**
     * @param value Whether to trust the server certificate
     */
    @JvmName("bwpkvyhequxmxion")
    public suspend fun trustServerCertificate(`value`: Output<Boolean>) {
        this.trustServerCertificate = value
    }

    /**
     * @param value Type of connection info
     * Expected value is 'SqlConnectionInfo'.
     */
    @JvmName("tcxhjxnvvdafeaes")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value User name
     */
    @JvmName("hapcqxqswsovhstf")
    public suspend fun userName(`value`: Output<String>) {
        this.userName = value
    }

    /**
     * @param value Additional connection settings
     */
    @JvmName("teipeqvygmhhojis")
    public suspend fun additionalSettings(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.additionalSettings = mapped
    }

    /**
     * @param value Authentication type to use for connection
     */
    @JvmName("vohkfnkvhkuvemxb")
    public suspend fun authentication(`value`: Either<String, AuthenticationType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authentication = mapped
    }

    /**
     * @param value Authentication type to use for connection
     */
    @JvmName("apsshoymxtljsjnr")
    public fun authentication(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AuthenticationType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authentication = mapped
    }

    /**
     * @param value Authentication type to use for connection
     */
    @JvmName("qybfwujusjxaeepk")
    public fun authentication(`value`: AuthenticationType) {
        val toBeMapped = Either.ofRight<String, AuthenticationType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authentication = mapped
    }

    /**
     * @param value Data source in the format Protocol:MachineName\SQLServerInstanceName,PortNumber
     */
    @JvmName("yntqwfvpndoohpqu")
    public suspend fun dataSource(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataSource = mapped
    }

    /**
     * @param value Whether to encrypt the connection
     */
    @JvmName("chlsqxbotxamhhrq")
    public suspend fun encryptConnection(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.encryptConnection = mapped
    }

    /**
     * @param value Password credential.
     */
    @JvmName("wievcakgnfjfcich")
    public suspend fun password(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.password = mapped
    }

    /**
     * @param value Server platform type for connection
     */
    @JvmName("eneesdmfugdoiaue")
    public suspend fun platform(`value`: Either<String, SqlSourcePlatform>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.platform = mapped
    }

    /**
     * @param value Server platform type for connection
     */
    @JvmName("ccxmbcpwrfgthxtj")
    public fun platform(`value`: String) {
        val toBeMapped = Either.ofLeft<String, SqlSourcePlatform>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.platform = mapped
    }

    /**
     * @param value Server platform type for connection
     */
    @JvmName("hkxyefcgjfeessyg")
    public fun platform(`value`: SqlSourcePlatform) {
        val toBeMapped = Either.ofRight<String, SqlSourcePlatform>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.platform = mapped
    }

    /**
     * @param value Whether to trust the server certificate
     */
    @JvmName("hsqdihkksxndgtvj")
    public suspend fun trustServerCertificate(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.trustServerCertificate = mapped
    }

    /**
     * @param value Type of connection info
     * Expected value is 'SqlConnectionInfo'.
     */
    @JvmName("plbkitxiejwsqaai")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value User name
     */
    @JvmName("ijgocbftgchlktqk")
    public suspend fun userName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userName = mapped
    }

    internal fun build(): SqlConnectionInfoArgs = SqlConnectionInfoArgs(
        additionalSettings = additionalSettings,
        authentication = authentication,
        dataSource = dataSource ?: throw PulumiNullFieldException("dataSource"),
        encryptConnection = encryptConnection,
        password = password,
        platform = platform,
        trustServerCertificate = trustServerCertificate,
        type = type ?: throw PulumiNullFieldException("type"),
        userName = userName,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/SqlConnectionInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.SqlConnectionInfoArgs.builder
import com.pulumi.azurenative.datamigration.kotlin.enums.AuthenticationType
import com.pulumi.azurenative.datamigration.kotlin.enums.SqlSourcePlatform
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Information for connecting to SQL database server
 * @property additionalSettings Additional connection settings
 * @property authentication Authentication type to use for connection
 * @property dataSource Data source in the format Protocol:MachineName\SQLServerInstanceName,PortNumber
 * @property encryptConnection Whether to encrypt the connection
 * @property password Password credential.
 * @property platform Server platform type for connection
 * @property trustServerCertificate Whether to trust the server certificate
 * @property type Type of connection info
 * Expected value is 'SqlConnectionInfo'.
 * @property userName User name
 */
public data class SqlConnectionInfoArgs(
    public val additionalSettings: Output<String>? = null,
    public val authentication: Output<Either<String, AuthenticationType>>? = null,
    public val dataSource: Output<String>,
    public val encryptConnection: Output<Boolean>? = null,
    public val password: Output<String>? = null,
    public val platform: Output<Either<String, SqlSourcePlatform>>? = null,
    public val trustServerCertificate: Output<Boolean>? = null,
    public val type: Output<String>,
    public val userName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.SqlConnectionInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.datamigration.inputs.SqlConnectionInfoArgs =
        com.pulumi.azurenative.datamigration.inputs.SqlConnectionInfoArgs.builder()
            .additionalSettings(additionalSettings?.applyValue({ args0 -> args0 }))
            .authentication(
                authentication?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .dataSource(dataSource.applyValue({ args0 -> args0 }))
            .encryptConnection(encryptConnection?.applyValue({ args0 -> args0 }))
            .password(password?.applyValue({ args0 -> args0 }))
            .platform(
                platform?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .trustServerCertificate(trustServerCertificate?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 }))
            .userName(userName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SqlConnectionInfoArgs].
 */
@PulumiTagMarker
public class SqlConnectionInfoArgsBuilder internal constructor() {
    private var additionalSettings: Output<String>? = null

    private var authentication: Output<Either<String, AuthenticationType>>? = null

    private var dataSource: Output<String>? = null

    private var encryptConnection: Output<Boolean>? = null

    private var password: Output<String>? = null

    private var platform: Output<Either<String, SqlSourcePlatform>>? = null

    private var trustServerCertificate: Output<Boolean>? = null

    private var type: Output<String>? = null

    private var userName: Output<String>? = null

    /**
     * @param value Additional connection settings
     */
    @JvmName("jxmxncudtssaltsv")
    public suspend fun additionalSettings(`value`: Output<String>) {
        this.additionalSettings = value
    }

    /**
     * @param value Authentication type to use for connection
     */
    @JvmName("nctxeleybkedkurx")
    public suspend fun authentication(`value`: Output<Either<String, AuthenticationType>>) {
        this.authentication = value
    }

    /**
     * @param value Data source in the format Protocol:MachineName\SQLServerInstanceName,PortNumber
     */
    @JvmName("ykwixkdfdypnqydt")
    public suspend fun dataSource(`value`: Output<String>) {
        this.dataSource = value
    }

    /**
     * @param value Whether to encrypt the connection
     */
    @JvmName("bvgacqdcjtcabgfc")
    public suspend fun encryptConnection(`value`: Output<Boolean>) {
        this.encryptConnection = value
    }

    /**
     * @param value Password credential.
     */
    @JvmName("gsvhxxysgbwagnpa")
    public suspend fun password(`value`: Output<String>) {
        this.password = value
    }

    /**
     * @param value Server platform type for connection
     */
    @JvmName("rsexupdrdwfjcxyr")
    public suspend fun platform(`value`: Output<Either<String, SqlSourcePlatform>>) {
        this.platform = value
    }

    /**
     * @param value Whether to trust the server certificate
     */
    @JvmName("vkuaxugmtvcgqapu")
    public suspend fun trustServerCertificate(`value`: Output<Boolean>) {
        this.trustServerCertificate = value
    }

    /**
     * @param value Type of connection info
     * Expected value is 'SqlConnectionInfo'.
     */
    @JvmName("suusaewmfsawqbfk")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value User name
     */
    @JvmName("widbqhnwijriledh")
    public suspend fun userName(`value`: Output<String>) {
        this.userName = value
    }

    /**
     * @param value Additional connection settings
     */
    @JvmName("gaaspxihjxqeejtt")
    public suspend fun additionalSettings(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.additionalSettings = mapped
    }

    /**
     * @param value Authentication type to use for connection
     */
    @JvmName("yxrlqlsonvbgmiaq")
    public suspend fun authentication(`value`: Either<String, AuthenticationType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authentication = mapped
    }

    /**
     * @param value Authentication type to use for connection
     */
    @JvmName("bhlrpuqrimbvgmti")
    public fun authentication(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AuthenticationType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authentication = mapped
    }

    /**
     * @param value Authentication type to use for connection
     */
    @JvmName("ingoejyurwxpfbhn")
    public fun authentication(`value`: AuthenticationType) {
        val toBeMapped = Either.ofRight<String, AuthenticationType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authentication = mapped
    }

    /**
     * @param value Data source in the format Protocol:MachineName\SQLServerInstanceName,PortNumber
     */
    @JvmName("udbjavtdjbgbihlu")
    public suspend fun dataSource(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataSource = mapped
    }

    /**
     * @param value Whether to encrypt the connection
     */
    @JvmName("gserpnhvdwghrbdl")
    public suspend fun encryptConnection(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.encryptConnection = mapped
    }

    /**
     * @param value Password credential.
     */
    @JvmName("fptyrnesddulbcgt")
    public suspend fun password(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.password = mapped
    }

    /**
     * @param value Server platform type for connection
     */
    @JvmName("oypvyysnnpfecgkc")
    public suspend fun platform(`value`: Either<String, SqlSourcePlatform>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.platform = mapped
    }

    /**
     * @param value Server platform type for connection
     */
    @JvmName("xlpwwbgvysbsvusu")
    public fun platform(`value`: String) {
        val toBeMapped = Either.ofLeft<String, SqlSourcePlatform>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.platform = mapped
    }

    /**
     * @param value Server platform type for connection
     */
    @JvmName("xthfyjkibiftymhk")
    public fun platform(`value`: SqlSourcePlatform) {
        val toBeMapped = Either.ofRight<String, SqlSourcePlatform>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.platform = mapped
    }

    /**
     * @param value Whether to trust the server certificate
     */
    @JvmName("shnnamfhmiwcndrf")
    public suspend fun trustServerCertificate(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.trustServerCertificate = mapped
    }

    /**
     * @param value Type of connection info
     * Expected value is 'SqlConnectionInfo'.
     */
    @JvmName("tnvavjlogygbshje")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value User name
     */
    @JvmName("mukvlghjwevxtjwh")
    public suspend fun userName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userName = mapped
    }

    internal fun build(): SqlConnectionInfoArgs = SqlConnectionInfoArgs(
        additionalSettings = additionalSettings,
        authentication = authentication,
        dataSource = dataSource ?: throw PulumiNullFieldException("dataSource"),
        encryptConnection = encryptConnection,
        password = password,
        platform = platform,
        trustServerCertificate = trustServerCertificate,
        type = type ?: throw PulumiNullFieldException("type"),
        userName = userName,
    )
}
